/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
 *
 * Copyright © 2017 Kinvolk GmbH
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Authors:
 *  - Krzesimir Nowak <krzesimir@kinvolk.io>
 */

#pragma once

#include <test-common/utils.h>

G_BEGIN_DECLS

/* Holds the single server and client, used by the functions
 * below. Normally you define a variable of this type on the stack and
 * pass an address to it to the etc_ functions.
 */
typedef struct
{
  EosUpdaterFixture *fixture;
  EosTestServer *server;
  EosTestSubserver *subserver;
  EosTestClient *client;
  GHashTable *additional_directories_for_commit;
  GHashTable *additional_files_for_commit;
  GHashTable *additional_metadata_for_commit;
} EtcData;

void etc_data_init (EtcData *data,
                    EosUpdaterFixture *fixture);

void etc_data_clear (EtcData *data);

G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC(EtcData, etc_data_clear);

void etc_set_up_server (EtcData *data);

void etc_set_up_client_synced_to_server (EtcData *data);

void etc_update_server (EtcData *data,
                        guint commit);

void etc_update_client (EtcData *data);
void etc_update_client_expect_failure (EtcData *data);
void etc_update_client_with_warnings (EtcData     *data,
                                      const gchar *expected_updater_warnings);

void etc_delete_object (GFile *repo,
                        const gchar *object);

void etc_delete_all_client_commits (EtcData *data);

G_END_DECLS
